# package-install-check

Checks if Python package installation worked.

This is a dummy package meant to be used in integration tests to check if automated Python package
installation is working.

## Usage

    from PackageInstallCheck import test
    print(test.it_works())
